@@ -313,10 +313,12 @@ class TernaryAxesSubplot(object):
         ax = self.get_axes()
         ax.legend(*args, **kwargs)
 
-    def savefig(self, filename, dpi=200, format=None):
+    def savefig(self, filename, **kwargs):
         self._redraw_labels()
         fig = self.get_figure()
-        fig.savefig(filename, format=format, dpi=dpi)
+        if 'dpi' not in kwargs:
+            kwargs['dpi'] = 200
+        fig.savefig(filename, **kwargs)
 
     def show(self):
         self._redraw_labels()
@@ -339,7 +341,7 @@ class TernaryAxesSubplot(object):
             self._ticks[k] = numpy.linspace(
                 self._axis_limits[k][0],
                 self._axis_limits[k][1],
-                self._boundary_scale / float(multiple) + 1
+                int(self._boundary_scale / float(multiple) + 1)
             ).tolist()
 
     def set_custom_ticks(self, locations=None, clockwise=False, multiple=1,
